==> okteta_0.25.5.orig.tar.xz: okteta-0.25.5/designer/oktetawidgetdesignerfactorycollection.cpp <==
/*
    This file is part of the Okteta Designer plugin, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "oktetawidgetdesignerfactorycollection.h"

// plugin
#include "bytearraycolumnviewdesignerfactory.h"
#include "bytearrayrowviewdesignerfactory.h"

OktetaWidgetDesignerFactoryCollection::OktetaWidgetDesignerFactoryCollection(QObject* parent)
    : QObject(parent)
{
    mWidgetFactories.append(new ByteArrayColumnViewDesignerFactory(this));
    mWidgetFactories.append(new ByteArrayRowViewDesignerFactory(this));
}

QList<QDesignerCustomWidgetInterface*> OktetaWidgetDesignerFactoryCollection::customWidgets() const
{
    return mWidgetFactories;
}

==> okteta-0.26.3.tar.xz: okteta-0.26.3/designer/oktetawidgetdesignerfactorycollection.cpp <==
/*
    This file is part of the Okteta Designer plugin, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "oktetawidgetdesignerfactorycollection.hpp"

// plugin
#include "bytearraycolumnviewdesignerfactory.hpp"
#include "bytearrayrowviewdesignerfactory.hpp"

OktetaWidgetDesignerFactoryCollection::OktetaWidgetDesignerFactoryCollection(QObject* parent)
    : QObject(parent)
{
    mWidgetFactories.append(new ByteArrayColumnViewDesignerFactory(this));
    mWidgetFactories.append(new ByteArrayRowViewDesignerFactory(this));
}

QList<QDesignerCustomWidgetInterface*> OktetaWidgetDesignerFactoryCollection::customWidgets() const
{
    return mWidgetFactories;
}
